@@ -626,7 +626,7 @@ setMethod("rbind", "Mnumber",
 unlistMpfr <- function(x, recursive = FALSE, use.names = TRUE)  {
     ## an "unlist(.)" for mpfr contents:
     if(recursive) stop("'recursive = TRUE' is not implemented (yet).")
-    n <- sum(vapply(x, length, 0L))
+    n <- sum(lengths(x))
     ans <- mpfr(numeric(n), precBits=3L)# dummy to fill
     ans@.Data <- unlist(lapply(x, slot, ".Data"), use.names=use.names)
     ans
@@ -681,7 +681,7 @@ applyMpfr <- function(X, MARGIN, FUN, ...)
 	## to use proper mode and dimension:
 	## The following is still a bit `hackish': use non-empty X
 	newX <- array(vector(typeof(X), 1L), dim = c(prod(d.call), 1L))
-	ans <- FUN(if(length(d.call) < 2L) newX[,1] else
+	ans <- forceAndCall(1, FUN, if(length(d.call) < 2L) newX[,1] else
 		   array(newX[, 1L], d.call, dn.call), ...)
 	return(if(is.null(ans)) ans else if(length(d.ans) < 2L) ans[1L][-1L]
 	       else array(ans, d.ans, dn.ans))
@@ -693,12 +693,12 @@ applyMpfr <- function(X, MARGIN, FUN, ...)
     if(length(d.call) < 2L) {# vector
 	if (length(dn.call)) dimnames(newX) <- c(dn.call, list(NULL))
 	for(i in 1L:d2) {
-	    tmp <- FUN(newX[,i], ...)
+	    tmp <- forceAndCall(1, FUN, newX[,i], ...)
 	    if(!is.null(tmp)) ans[[i]] <- tmp
 	}
     } else
        for(i in 1L:d2) {
-	   tmp <- FUN(array(newX[,i], d.call, dn.call), ...)
+	   tmp <- forceAndCall(1, FUN, array(newX[,i], d.call, dn.call), ...)
 	   if(!is.null(tmp)) ans[[i]] <- tmp
 	}
 
@@ -709,7 +709,7 @@ applyMpfr <- function(X, MARGIN, FUN, ...)
 
     ans.names <- names(ans[[1L]])
     if(!ans.list)
-	ans.list <- any(unlist(lapply(ans, length)) != l.ans)
+	ans.list <- any(lengths(ans) != l.ans)
     if(!ans.list && length(ans.names)) {
 	all.same <- vapply(ans, function(x) identical(names(x), ans.names), NA)
 	if (!all(all.same)) ans.names <- NULL
@@ -717,17 +717,22 @@ applyMpfr <- function(X, MARGIN, FUN, ...)
     len.a <- if(ans.list) d2 else length(ans <- unlistMpfr(ans))
     if(length(MARGIN) == 1L && len.a == d2) {
 	names(ans) <- if(length(dn.ans[[1L]])) dn.ans[[1L]] # else NULL
-	return(ans)
+	ans
     }
-    if(len.a == d2)
-	return(array(ans, d.ans, dn.ans))
-    if(len.a && len.a %% d2 == 0L) {
+    else if(len.a == d2)
+	array(ans, d.ans, dn.ans)
+    else if(len.a && len.a %% d2 == 0L) {
 	if(is.null(dn.ans)) dn.ans <- vector(mode="list", length(d.ans))
-	dn.ans <- c(list(ans.names), dn.ans)
-	return(array(ans, c(len.a %/% d2, d.ans),
-		     if(!all(vapply(dn.ans, is.null, NA))) dn.ans))
-    }
-    return(ans)
+	dn1 <- list(ans.names)
+	if(length(dn.call) && !is.null(n1 <- names(dn <- dn.call[1])) &&
+	   nzchar(n1) && length(ans.names) == length(dn[[1]]))
+	    names(dn1) <- n1
+	dn.ans <- c(dn1, dn.ans)
+	array(ans, c(len.a %/% d2, d.ans),
+	      if(!is.null(names(dn.ans)) || !all(vapply(dn.ans, is.null, NA)))
+		  dn.ans)
+    } else
+	ans
 }
 
 setGeneric("apply")
